@@ -1,9 +1,18 @@
 '''Two different implementation of a redis::map, a networked
 ordered associative container
 '''
+from itertools import izip, imap
 import base as structures
 
 
+def riteritems(self, com, *rargs):
+    res = self.cursor.execute_command(com, self.id, *rargs)
+    if res:
+        return izip(res[::2], res[1::2])
+    else:
+        return res
+
+
 class List(structures.List):
     
     def _size(self):
@@ -110,13 +119,17 @@ class HashTable(structures.HashTable):
         return self.cursor.execute_command('HDEL', self.id, key)
     
     def _contains(self, value):
-        return self.cursor.execute_command('HEXISTS', self.id, value) is not None
+        if self.cursor.execute_command('HEXISTS', self.id, value):
+            return True
+        else:
+            return False
         
     def _keys(self):
         return self.cursor.execute_command('HKEYS', self.id)
     
     def _items(self):
-        return self.cursor.execute_command('HGETALL', self.id)
+        return self.cursor.execute_command('HGETALL', self.id).iteritems()
+        #return riteritems(self, 'HGETALL', self.id)
 
     def values(self):
         for ky,val in self.items():
@@ -130,3 +143,61 @@ class HashTable(structures.HashTable):
     def add_expiry(self):
         self.cursor.execute_command('EXPIRE', self.id, self.timeout)
         
+
+class Map(structures.Map):
+    '''Requires Redis Map structure which is not yet implemented in redis (and I don't know if it will).
+It is implemented on my redis-fork at https://github.com/lsbardel/redis'''
+    def _size(self):
+        return self.cursor.execute_command('TLEN', self.id)
+    
+    def clear(self):
+        return self.cursor.execute_command('DEL', self.id)
+    
+    def _get(self, key):
+        return self.cursor.execute_command('TGET', self.id, key)
+    
+    def _mget(self, keys):
+        return self.cursor.execute_command('TMGET', self.id, *keys)
+    
+    def delete(self, key):
+        return self.cursor.execute_command('TDEL', self.id, key)
+    
+    def _contains(self, key):
+        if self.cursor.execute_command('TEXISTS', self.id, key):
+            return True
+        else:
+            return False
+        
+    def _irange(self, start, end):
+        return riteritems(self, 'TRANGE', start, end, 'withvalues')
+    
+    def _range(self, start, end):
+        return riteritems(self, 'TRANGEBYSCORE', start, end, 'withvalues')
+    
+    def _count(self, start, end):
+        return self.cursor.execute_command('TCOUNT', self.id, start, end)
+    
+    def _front(self):
+        return self.cursor.execute_command('THEAD', self.id)
+    
+    def _back(self):
+        return self.cursor.execute_command('TTAIL', self.id)
+        
+    def _keys(self):
+        return self.cursor.execute_command('TKEYS', self.id)
+    
+    def _items(self):
+        return riteritems(self, 'TITEMS')
+
+    def values(self):
+        for ky,val in self.items():
+            yield val
+            
+    def _save(self):
+        items = []
+        [items.extend(item) for item in self.pipeline.items3()]
+        return self.cursor.execute_command('TADD',self.id,*items)
+    
+    def add_expiry(self):
+        self.cursor.execute_command('EXPIRE', self.id, self.timeout)
+        
\ No newline at end of file
